summaryrefslogtreecommitdiffstats
path: root/kjsembed/qtbindings/qcanvasspline_imp.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/qtbindings/qcanvasspline_imp.cpp')
-rw-r--r--kjsembed/qtbindings/qcanvasspline_imp.cpp64
1 files changed, 32 insertions, 32 deletions
diff --git a/kjsembed/qtbindings/qcanvasspline_imp.cpp b/kjsembed/qtbindings/qcanvasspline_imp.cpp
index 54edeb8f..26e4c4c7 100644
--- a/kjsembed/qtbindings/qcanvasspline_imp.cpp
+++ b/kjsembed/qtbindings/qcanvasspline_imp.cpp
@@ -23,19 +23,19 @@
*/
namespace KJSEmbed {
-QCanvasSplineImp::QCanvasSplineImp( KJS::ExecState *exec, int mid, bool constructor )
+TTQCanvasSplineImp::TQCanvasSplineImp( KJS::ExecState *exec, int mid, bool constructor )
: JSProxyImp(exec), id(mid), cons(constructor)
{
}
-QCanvasSplineImp::~QCanvasSplineImp()
+TTQCanvasSplineImp::~TQCanvasSplineImp()
{
}
/**
* Adds bindings for static methods and enum constants to the specified Object.
*/
-void QCanvasSplineImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &object )
+void TQCanvasSplineImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &object )
{
JSProxy::MethodTable methods[] = {
@@ -43,11 +43,11 @@ void QCanvasSplineImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &obj
};
int idx = 0;
- TQCString lastName;
+ TTQCString lastName;
while( methods[idx].name ) {
if ( lastName != methods[idx].name ) {
- QCanvasSplineImp *meth = new QCanvasSplineImp( exec, methods[idx].id );
+ TQCanvasSplineImp *meth = new TQCanvasSplineImp( exec, methods[idx].id );
object.put( exec , methods[idx].name, KJS::Object(meth) );
lastName = methods[idx].name;
}
@@ -60,7 +60,7 @@ void QCanvasSplineImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &obj
/**
* Adds bindings for instance methods to the specified Object.
*/
-void QCanvasSplineImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
+void TQCanvasSplineImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
{
JSProxy::MethodTable methods[] = {
@@ -72,11 +72,11 @@ void QCanvasSplineImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
};
int idx = 0;
- TQCString lastName;
+ TTQCString lastName;
while( methods[idx].name ) {
if ( lastName != methods[idx].name ) {
- QCanvasSplineImp *meth = new QCanvasSplineImp( exec, methods[idx].id );
+ TQCanvasSplineImp *meth = new TQCanvasSplineImp( exec, methods[idx].id );
object.put( exec , methods[idx].name, KJS::Object(meth) );
lastName = methods[idx].name;
}
@@ -85,68 +85,68 @@ void QCanvasSplineImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
}
/**
* Extract a TQCanvasSpline pointer from an Object.
*/
-TQCanvasSpline *QCanvasSplineImp::toQCanvasSpline( KJS::Object &self )
+TTQCanvasSpline *TQCanvasSplineImp::toTQCanvasSpline( KJS::Object &self )
{
JSObjectProxy *ob = JSProxy::toObjectProxy( self.imp() );
if ( ob ) {
- TQObject *obj = ob->object();
+ TTQObject *obj = ob->object();
if ( obj )
- return dynamic_cast<TQCanvasSpline *>( obj );
+ return dynamic_cast<TTQCanvasSpline *>( obj );
}
JSOpaqueProxy *op = JSProxy::toOpaqueProxy( self.imp() );
if ( !op )
return 0;
- if ( op->typeName() != "TQCanvasSpline" )
+ if ( op->typeName() != "TTQCanvasSpline" )
return 0;
- return op->toNative<TQCanvasSpline>();
+ return op->toNative<TTQCanvasSpline>();
}
/**
* Select and invoke the correct constructor.
*/
-KJS::Object QCanvasSplineImp::construct( KJS::ExecState *exec, const KJS::List &args )
+KJS::Object TQCanvasSplineImp::construct( KJS::ExecState *exec, const KJS::List &args )
{
switch( id ) {
case Constructor_QCanvasSpline_1:
- return QCanvasSpline_1( exec, args );
+ return TQCanvasSpline_1( exec, args );
break;
default:
break;
}
- TQString msg = i18n("QCanvasSplineCons has no constructor with id '%1'.").arg(id);
+ TTQString msg = i18n("TQCanvasSplineCons has no constructor with id '%1'.").arg(id);
return throwError(exec, msg,KJS::ReferenceError);
}
-KJS::Object QCanvasSplineImp::QCanvasSpline_1( KJS::ExecState *exec, const KJS::List &args )
+KJS::Object TQCanvasSplineImp::TQCanvasSpline_1( KJS::ExecState *exec, const KJS::List &args )
{
// Unsupported parameter TQCanvas *
return KJS::Object();
- TQCanvas * arg0; // Dummy
+ TTQCanvas * arg0; // Dummy
- // We should now create an instance of the TQCanvasSpline object
+ // We should now create an instance of the TTQCanvasSpline object
- TQCanvasSpline *ret = new TQCanvasSpline(
+ TTQCanvasSpline *ret = new TTQCanvasSpline(
arg0 );
}
-KJS::Value QCanvasSplineImp::call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args )
+KJS::Value TQCanvasSplineImp::call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args )
{
- instance = QCanvasSplineImp::toQCanvasSpline( self );
+ instance = TQCanvasSplineImp::toTQCanvasSpline( self );
switch( id ) {
@@ -170,18 +170,18 @@ KJS::Value QCanvasSplineImp::call( KJS::ExecState *exec, KJS::Object &self, cons
break;
}
- TQString msg = i18n( "QCanvasSplineImp has no method with id '%1'." ).arg( id );
+ TTQString msg = i18n( "TQCanvasSplineImp has no method with id '%1'." ).arg( id );
return throwError(exec, msg,KJS::ReferenceError);
}
-KJS::Value QCanvasSplineImp::setControlPoints_3( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasSplineImp::setControlPoints_3( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- // Unsupported parameter QPointArray
+ // Unsupported parameter TQPointArray
return KJS::Value();
- TQPointArray arg0; // Dummy
+ TTQPointArray arg0; // Dummy
bool arg1 = extractBool(exec, args, 1);
@@ -192,15 +192,15 @@ KJS::Value QCanvasSplineImp::setControlPoints_3( KJS::ExecState *exec, KJS::Obje
}
-KJS::Value QCanvasSplineImp::controlPoints_4( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasSplineImp::controlPoints_4( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
instance->controlPoints( );
- return KJS::Value(); // Returns 'QPointArray'
+ return KJS::Value(); // Returns 'TQPointArray'
}
-KJS::Value QCanvasSplineImp::closed_5( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasSplineImp::closed_5( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
bool ret;
@@ -209,7 +209,7 @@ KJS::Value QCanvasSplineImp::closed_5( KJS::ExecState *exec, KJS::Object &obj, c
}
-KJS::Value QCanvasSplineImp::rtti_6( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasSplineImp::rtti_6( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
int ret;
@@ -85,68 +85,68 @@ void QCanvasSplineImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
}
/**
- * Extract a TQCanvasSpline pointer from an Object.
+ * Extract a TTQCanvasSpline pointer from an Object.
*/
@@ -85,68 +85,68 @@ void QCanvasSplineImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
{
- // Unsupported parameter TQCanvas *
+ // Unsupported parameter TTQCanvas *
return KJS::Object();